@@ -33,3 +33,9 @@ export {SpecialFolderIcon} from '../app/specialFolderIcon.js';
 export {ShortcutManager} from '../app/shortcutManager.js';
 export {DefaultShortcuts} from '../app/shortcuts.js';
 export {GlobalShortcuts} from '../app/shortcuts.js';
+export * as WidgetManager from '../app/widgetManager.js';
+export {WidgetRegistry} from '../app/widgetRegistry.js';
+export {HtmlWidgetHost} from '../app/htmlWidgetHost.js';
+export * as WidgetApi from '../app/widgetApi.js';
+export {FallbackHtml} from '../app/fallbackHtml.js';
+export {WebWidgetContext} from '../app/widgetWebContext.js';
